-- | Partial functions. Import as:
--
-- > import qualified RIO.Partial as RIO'
module RIO.Partial
  ( Data.Maybe.fromJust
  , Prelude.read
  , Prelude.toEnum
  , Prelude.pred
  , Prelude.succ
  ) where

import qualified Data.Maybe
import qualified Prelude
