-- | Strict @HashMap@ partial functions. Import as:
--
-- > import qualified RIO.HashMap.Partial as HM'
module RIO.HashMap.Partial
  (
  -- * Basic interface
    (Data.HashMap.Strict.!)
  ) where

import qualified Data.HashMap.Strict
