-- | Unicode @Char@ partial functions. Import as:
--
-- > import qualified RIO.Char.Partial as C'
module RIO.Char.Partial
  (
  -- * Single digit characters
    Data.Char.digitToInt
  , Data.Char.intToDigit

  -- * Numeric representations
  , Data.Char.chr
  ) where

import qualified Data.Char
