-- | @NonEmpty@ list partial functions. Import as:
--
-- > import qualified RIO.NonEmpty.Partial as NE'
module RIO.NonEmpty.Partial
  (
  -- * Indexing streams
    (Data.List.NonEmpty.!!)

  -- * Converting to and from a list
  , Data.List.NonEmpty.fromList

  ) where

import qualified Data.List.NonEmpty
